@@ -9,16 +9,20 @@ class SabaTV1: public PIRKeysetMetaData
 {
 public:
   SabaTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SabaTV2: public PIRKeysetMetaData
 {
 public:
   SabaTV2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // SABA_H
