@@ -10,7 +10,9 @@
 #include "keysets/apple.h"
 #include "keysets/beko.h"
 #include "keysets/bose.h"
+#include "keysets/bush.h"
 #include "keysets/cambridge.h"
+#include "keysets/canon.h"
 #include "keysets/daewoo.h"
 #include "keysets/denon.h"
 #include "keysets/digitalstream.h"
@@ -19,6 +21,7 @@
 #include "keysets/ei.h"
 #include "keysets/elgato.h"
 #include "keysets/emerson.h"
+#include "keysets/epson.h"
 #include "keysets/fortec.h"
 #include "keysets/goldstar.h"
 #include "keysets/grundig.h"
@@ -28,6 +31,7 @@
 #include "keysets/homecast.h"
 #include "keysets/hp.h"
 #include "keysets/huawei.h"
+#include "keysets/humax.h"
 #include "keysets/jvc.h"
 #include "keysets/kenwood.h"
 #include "keysets/lg.h"
@@ -53,9 +57,11 @@
 #include "keysets/sharp.h"
 #include "keysets/sky.h"
 #include "keysets/sony.h"
+#include "keysets/technics.h"
 #include "keysets/tivo.h"
 #include "keysets/topfield.h"
 #include "keysets/toshiba.h"
+#include "keysets/united.h"
 #include "keysets/vestel.h"
 #include "keysets/virgin.h"
 #include "keysets/vizio.h"
@@ -115,12 +121,20 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new BoseRadio3(counter++));
   setupKeyset(new BoseHomeTheater1(counter++));
 
+  setupKeyset(new BushTV1(counter++));
+  setupKeyset(new BushTV2(counter++));
+  setupKeyset(new BushSTB1(counter++));
+
   setupKeyset(new CambridgeCD1(counter++));
   setupKeyset(new CambridgeAudio1(counter++));
   setupKeyset(new CambridgeAudio2(counter++));
   setupKeyset(new CambridgeAudio3(counter++));
   setupKeyset(new CambridgeDVD1(counter++));
 
+  setupKeyset(new CanonDSLR1(counter++));
+  setupKeyset(new CanonCamcorder1(counter++));
+  setupKeyset(new CanonPowershot1(counter++));
+
   setupKeyset(new DaewooTV1(counter++));
   setupKeyset(new DaewooTV2(counter++));
   setupKeyset(new DaewooTV3(counter++));
@@ -179,6 +193,9 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new EmersonTV1(counter++));
   setupKeyset(new EmersonDVD1(counter++));
 
+  setupKeyset(new EpsonProjector1(counter++));
+  setupKeyset(new EpsonProjector2(counter++));
+
   setupKeyset(new FortecReceiver1(counter++));
   setupKeyset(new FortecReceiver2(counter++));
 
@@ -229,6 +246,10 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new HuaweiSTB1(counter++));
   setupKeyset(new HuaweiSTB2(counter++));
 
+  setupKeyset(new HumaxReceiver1(counter++));
+  setupKeyset(new HumaxReceiver2(counter++));
+  setupKeyset(new HumaxReceiver3(counter++));
+
   setupKeyset(new JVCSat1(counter++));
   setupKeyset(new JVCSat2(counter++));
   setupKeyset(new JVCVCR1(counter++));
@@ -316,6 +337,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new PanasonicDVD1(counter++));
   setupKeyset(new PanasonicDVD1a(counter++));
   setupKeyset(new PanasonicAudio1(counter++));
+  setupKeyset(new PanasonicAudio2(counter++));
   setupKeyset(new PanasonicAC1(counter++));
 
   setupKeyset(new PhilcoTV(counter++));
@@ -458,6 +480,13 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new SonyVCR1b(counter++));
   setupKeyset(new SonyReceiver1(counter++));
 
+  setupKeyset(new TechnicsAudio1(counter++));
+  setupKeyset(new TechnicsAudio1a(counter++));
+  setupKeyset(new TechnicsAudio2(counter++));
+  setupKeyset(new TechnicsAudio3(counter++));
+  setupKeyset(new TechnicsAudio3a(counter++));
+  setupKeyset(new TechnicsDVD1(counter++));
+
   setupKeyset(new Tivo1(counter++));
   setupKeyset(new Tivo1a(counter++));
   setupKeyset(new Tivo1b(counter++));
@@ -484,6 +513,9 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new ToshibaDisc1c(counter++));
   setupKeyset(new ToshibaDisc1d(counter++));
 
+  setupKeyset(new UnitedDVD1(counter++));
+  setupKeyset(new UnitedDVBT1(counter++));
+
   setupKeyset(new VestelTV1(counter++));
   setupKeyset(new VestelTV2(counter++));
 
